<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/user_input_handler_registry.php';
require_once 'lib/utils.php';
require_once 'lib/action_factory.php';
require_once 'lib/control_factory.php';

///////////////////////////////////////////////////////////////////////////

class HtmlDemoInputHandler implements UserInputHandler
{
    public function __construct()
    {
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id()
    { return "main_handler"; }

    ///////////////////////////////////////////////////////////////////////

    private function get_dialog_defs()
    {
        $defs = array();

        ControlFactory::add_vgap($defs, 20);

        ControlFactory::add_button($defs, $this, null,
            'launch1', 'Page "index.html":', 'Launch Browser', 0);
        ControlFactory::add_button($defs, $this, null,
            'launch2', 'Page "playback.html":', 'Launch Browser', 0);
        ControlFactory::add_button($defs, $this, null,
            'launch3', 'Page "google.com"', "Launch Browser", 0);

        ControlFactory::add_vgap($defs, 20);

        ControlFactory::add_close_dialog_button($defs, 'Cancel', 200,
            array('button_caption_centered' => 1));

        return $defs;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('HtmlDemo: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if (isset($user_input->control_id))
        {
            if ($user_input->control_id == 'launch1')
            {
                return ActionFactory::launch_media_url(
                    'www://http://127.0.0.1/plugins/html_demo/index.html:::fullscreen=1&webapp_keys=1&zoom_level=100&overscan=0&osd_size=1280x720');
            }

            if ($user_input->control_id == 'launch2')
            {
                return ActionFactory::launch_media_url(
                    'www://http://127.0.0.1/plugins/html_demo/playback.html:::fullscreen=1&webapp_keys=1&zoom_level=100&overscan=0&osd_size=1280x720');
            }

            if ($user_input->control_id == 'launch3')
            {
                return ActionFactory::launch_media_url(
                    'www://http://google.com');
            }

            return null;
        }

        if (!isset($user_input->op))
            return ActionFactory::show_dialog(true, "Illegal state");

        if ($user_input->op == 'do_work_and_launch_html')
        {
            // Do something before launching browser...
            system("touch /tmp/file1");
            hd_print('Sleeping...');
            sleep(1);
            system("touch /tmp/file2");
            hd_print('Sleeping...');
            sleep(1);
            system("touch /tmp/file3");
            hd_print('Sleeping...');
            sleep(1);
            system("touch /tmp/file4");

            return ActionFactory::launch_media_url(
                'www://http://127.0.0.1/plugins/html_demo/index.html:::fullscreen=1&webapp_keys=1&zoom_level=100&overscan=0&osd_size=1280x720');
        }

        if ($user_input->op == 'show_dialog')
        {
            return ActionFactory::show_dialog('Choose Action',
                $this->get_dialog_defs(), true);
        }

        return null;
    }
}

class HtmlDemoPlugin implements DunePlugin
{
    private $handler;

    public function __construct()
    {
        $handler = new HtmlDemoInputHandler();
    }

    ///////////////////////////////////////////////////////////////////////
    // Implementation of DunePlugin interface.
    // Only handle_user_input() is really implemented, other operations are
    // not supported in current plugin.

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        return UserInputHandlerRegistry::get_instance()->handle_user_input(
            $user_input, $plugin_cookies);
    }

    public function get_folder_view($media_url_str, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_next_folder_view($media_url_str, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_regular_folder_items($media_url_str, $from_ndx,
        &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_tv_info($media_url_str, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_tv_stream_url($playback_url, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_day_epg($channel_id, $day_start_ts, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function change_tv_favorites($fav_op_type, $channel_id, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_vod_info($media_url_str, &$plugin_cookies)
    { throw new Exception("Not supported"); }

    public function get_vod_stream_url($playback_url, &$plugin_cookies)
    { throw new Exception("Not supported"); }
}

///////////////////////////////////////////////////////////////////////////
?>
